summaryrefslogtreecommitdiff
path: root/pango/opentype/hb-open-type-private.hh
diff options
context:
space:
mode:
Diffstat (limited to 'pango/opentype/hb-open-type-private.hh')
-rw-r--r--pango/opentype/hb-open-type-private.hh6
1 files changed, 3 insertions, 3 deletions
diff --git a/pango/opentype/hb-open-type-private.hh b/pango/opentype/hb-open-type-private.hh
index 075dc831..59e0fb50 100644
--- a/pango/opentype/hb-open-type-private.hh
+++ b/pango/opentype/hb-open-type-private.hh
@@ -217,7 +217,7 @@ _hb_sanitize_edit (SANITIZE_ARG_DEF,
const char *base HB_GNUC_UNUSED,
unsigned int len HB_GNUC_UNUSED)
{
- bool perm = hb_blob_try_writeable_inplace (context->blob);
+ bool perm = hb_blob_try_writable_inplace (context->blob);
context->edit_count++;
#if HB_DEBUG
@@ -298,8 +298,8 @@ struct Sanitizer
} else {
unsigned int edit_count = context.edit_count;
_hb_sanitize_fini (&context, true);
- if (edit_count && !hb_blob_is_writeable (blob) && hb_blob_try_writeable (blob)) {
- /* ok, we made it writeable by relocating. try again */
+ if (edit_count && !hb_blob_is_writable (blob) && hb_blob_try_writable (blob)) {
+ /* ok, we made it writable by relocating. try again */
#if HB_DEBUG
fprintf (stderr, "Sanitizer %p retry %s\n", blob, __PRETTY_FUNCTION__);
#endif